@@ -111,7 +111,11 @@ Qt::ItemFlags MenuProxyModel::flags(const QModelIndex &index) const
     }
 
     QString matchText = index.data(MenuModel::UserFilterRole).toString();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QRegExp pattern = KCategorizedSortFilterProxyModel::filterRegExp();
+#else
+    QRegularExpression pattern = KCategorizedSortFilterProxyModel::filterRegularExpression();
+#endif
 
     if (!matchText.contains(pattern)) {
         return Qt::NoItemFlags;
@@ -120,6 +124,7 @@ Qt::ItemFlags MenuProxyModel::flags(const QModelIndex &index) const
     }
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void MenuProxyModel::setFilterRegExp(const QString &pattern)
 {
     if (pattern == filterRegExp()) {
@@ -142,3 +147,27 @@ void MenuProxyModel::setFilterRegExp(const QRegExp &regExp)
     KCategorizedSortFilterProxyModel::setFilterRegExp(regExp);
     Q_EMIT layoutChanged();
 }
+#else
+void MenuProxyModel::setFilterRegularExpression(const QString &pattern)
+{
+    if (pattern == filterRegularExpression()) {
+        return;
+    }
+    Q_EMIT layoutAboutToBeChanged();
+    KCategorizedSortFilterProxyModel::setFilterRegularExpression(pattern);
+    Q_EMIT layoutChanged();
+    Q_EMIT filterRegularExpressionChanged();
+}
+
+QString MenuProxyModel::filterRegularExpression() const
+{
+    return KCategorizedSortFilterProxyModel::filterRegularExpression().pattern();
+}
+
+void MenuProxyModel::setFilterRegularExpression(const QRegularExpression &regExp)
+{
+    Q_EMIT layoutAboutToBeChanged();
+    KCategorizedSortFilterProxyModel::setFilterRegularExpression(regExp);
+    Q_EMIT layoutChanged();
+}
+#endif
